@@ -991,7 +991,12 @@ xfce_panel_plugin_button_press_event (GtkWidget      *widget,
         gtk_widget_set_sensitive (item, plugin->priv->menu_blocked == 0);
 
       /* popup the menu */
-      gtk_menu_popup (menu, NULL, NULL, NULL, NULL, event->button, event->time);
+#if GTK_CHECK_VERSION (3, 22, 0)
+      gtk_menu_popup_at_pointer (menu, (GdkEvent *) event);
+#else
+      gtk_menu_popup (menu, NULL, NULL, NULL, NULL,
+                      event->button, event->time);
+#endif
 
       return TRUE;
     }
@@ -1193,7 +1198,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
               G_CALLBACK (xfce_panel_plugin_show_configure), plugin);
           g_object_set_qdata (G_OBJECT (menu), item_properties, item);
           gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-          image = gtk_image_new_from_icon_name ("gtk-properties", GTK_ICON_SIZE_MENU);
+          image = gtk_image_new_from_icon_name ("document-properties", GTK_ICON_SIZE_MENU);
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
           gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
 G_GNUC_END_IGNORE_DEPRECATIONS
@@ -1208,7 +1213,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
               G_CALLBACK (xfce_panel_plugin_show_about), plugin);
           g_object_set_qdata (G_OBJECT (menu), item_about, item);
           gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-          image = gtk_image_new_from_icon_name ("gtk-about", GTK_ICON_SIZE_MENU);
+          image = gtk_image_new_from_icon_name ("help-about", GTK_ICON_SIZE_MENU);
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
           gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
 G_GNUC_END_IGNORE_DEPRECATIONS
@@ -1248,7 +1253,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
           gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
           gtk_widget_show (item);
 
-          image = gtk_image_new_from_icon_name ("gtk-remove", GTK_ICON_SIZE_MENU);
+          image = gtk_image_new_from_icon_name ("list-remove", GTK_ICON_SIZE_MENU);
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
           gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
 G_GNUC_END_IGNORE_DEPRECATIONS
