@@ -61,6 +61,10 @@ static gboolean     panel_item_dialog_separator_func         (GtkTreeModel
 static void         panel_item_dialog_selection_changed      (GtkTreeSelection   *selection,
                                                               PanelItemDialog    *dialog);
 static PanelModule *panel_item_dialog_get_selected_module    (GtkTreeView        *treeview);
+static void         panel_item_dialog_row_activated          (GtkTreeView        *treeview,
+                                                              GtkTreePath        *path,
+                                                              GtkTreeViewColumn  *column,
+                                                              gpointer            user_data);
 static void         panel_item_dialog_drag_begin             (GtkWidget          *treeview,
                                                               GdkDragContext     *context,
                                                               PanelItemDialog    *dialog);
@@ -195,7 +199,7 @@ panel_item_dialog_init (PanelItemDialog *dialog)
   gtk_window_set_type_hint (GTK_WINDOW (dialog), GDK_WINDOW_TYPE_HINT_NORMAL);
 
   icon = gtk_image_new_from_icon_name ("list-add", GTK_ICON_SIZE_BUTTON);
-  dialog->add_button = gtk_button_new_with_mnemonic ("_Add");
+  dialog->add_button = gtk_button_new_with_mnemonic (_("_Add"));
   gtk_button_set_image (GTK_BUTTON (dialog->add_button), icon);
   gtk_widget_show_all (dialog->add_button);
 
@@ -256,6 +260,7 @@ panel_item_dialog_init (PanelItemDialog *dialog)
 
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
   g_signal_connect (G_OBJECT (selection), "changed", G_CALLBACK (panel_item_dialog_selection_changed), dialog);
+  g_signal_connect (G_OBJECT (treeview), "row-activated", G_CALLBACK (panel_item_dialog_row_activated), dialog);
 
   g_object_unref (G_OBJECT (filter));
 
@@ -485,6 +490,19 @@ panel_item_dialog_get_selected_module (GtkTreeView *treeview)
 
 
 
+static void
+panel_item_dialog_row_activated (GtkTreeView *treeview,
+                                 GtkTreePath *path,
+                                 GtkTreeViewColumn *column,
+                                 gpointer user_data)
+{
+  GtkDialog *dialog = GTK_DIALOG (user_data);
+
+  panel_item_dialog_response (dialog, GTK_RESPONSE_OK);
+}
+
+
+
 static void
 panel_item_dialog_drag_begin (GtkWidget       *treeview,
                               GdkDragContext  *context,
@@ -609,7 +627,7 @@ panel_item_dialog_populate_store (PanelItemDialog *dialog)
 
   /* add an empty item for separator in 2nd position */
   if (panel_module_factory_has_launcher (dialog->factory))
-    gtk_list_store_insert_with_values (dialog->store, &iter, 1,
+    gtk_list_store_insert_with_values (dialog->store, &iter, 2,
                                        COLUMN_MODULE, NULL, -1);
 }
 
@@ -648,6 +666,18 @@ panel_item_dialog_compare_func (GtkTreeModel *model,
       /* move the launcher to the first position */
       result = 1;
     }
+  else if (g_strcmp0 (SEPARATOR_PLUGIN_NAME,
+                      panel_module_get_name (module_a)) == 0)
+    {
+      /* move the separator to the second position */
+      result = -1;
+    }
+  else if (g_strcmp0 (SEPARATOR_PLUGIN_NAME,
+                      panel_module_get_name (module_b)) == 0)
+    {
+      /* move the separator to the second position */
+      result = 1;
+    }
   else
     {
       /* get the visible module names */
