@@ -492,16 +492,17 @@ panel_preferences_dialog_bindings_update (PanelPreferencesDialog *dialog)
       gtk_list_store_insert_with_values (GTK_LIST_STORE (store), &iter, n++,
                                          OUTPUT_NAME, "Automatic",
                                          OUTPUT_TITLE, _("Automatic"), -1);
-      if (g_strcmp0 (output_name, "Automatic") == 0) {
-        gtk_combo_box_set_active_iter (GTK_COMBO_BOX (object), &iter);
-        output_selected = TRUE;
-        span_monitors_sensitive = TRUE;
-      }
+      if (panel_str_is_empty (output_name) ||
+          g_strcmp0 (output_name, "Automatic") == 0)
+        {
+          gtk_combo_box_set_active_iter (GTK_COMBO_BOX (object), &iter);
+          output_selected = TRUE;
+          span_monitors_sensitive = TRUE;
+        }
       gtk_list_store_insert_with_values (GTK_LIST_STORE (store), &iter, n++,
                                          OUTPUT_NAME, "Primary",
                                          OUTPUT_TITLE, _("Primary"), -1);
-      if (panel_str_is_empty (output_name) ||
-          g_strcmp0 (output_name, "Primary") == 0)
+      if (g_strcmp0 (output_name, "Primary") == 0)
         {
           gtk_combo_box_set_active_iter (GTK_COMBO_BOX (object), &iter);
           output_selected = TRUE;
@@ -1513,16 +1514,10 @@ panel_preferences_dialog_show (PanelWindow *active)
 
 void
 panel_preferences_dialog_show_from_id (gint         panel_id,
-                                       const gchar *socket_id)
+                                       Window       socket_window)
 {
   PanelApplication *application;
   PanelWindow      *window;
-  Window            socket_window = 0;
-
-  /* x11 windows are ulong on 64 bit platforms
-   * or uint32 on other platforms */
-  if (socket_id != NULL)
-    socket_window = (Window) strtoul (socket_id, NULL, 0);
 
   application = panel_application_get ();
   window = panel_application_get_window (application, panel_id);
