@@ -771,6 +771,34 @@ clock_plugin_configure_plugin_chooser_separator (GtkTreeModel *model,
 
 
 
+static void
+clock_plugin_validate_format_specifier (GtkEntry *entry, gchar *format, ClockPlugin *plugin)
+{
+  GtkStyleContext *context;
+
+  context = gtk_widget_get_style_context (GTK_WIDGET (entry));
+
+  if (!clock_time_strdup_strftime (plugin->time, format))
+    gtk_style_context_add_class (context, "error");
+  else
+    gtk_style_context_remove_class (context, "error");
+}
+
+
+
+static void
+clock_plugin_validate_entry_text (GtkEditable *entry,
+                                  gpointer user_data)
+{
+  ClockPlugin *plugin = user_data;
+
+  clock_plugin_validate_format_specifier (entry,
+                                          gtk_entry_get_text(GTK_ENTRY (entry)),
+                                          plugin);
+}
+
+
+
 static void
 clock_plugin_configure_plugin_chooser_fill (ClockPlugin *plugin,
                                             GtkComboBox *combo,
@@ -799,19 +827,27 @@ clock_plugin_configure_plugin_chooser_fill (ClockPlugin *plugin,
   for (i = 0; formats[i] != NULL; i++)
     {
       preview = clock_time_strdup_strftime (plugin->time, _(formats[i]));
-      gtk_list_store_insert_with_values (store, &iter, i,
-                                         COLUMN_FORMAT, _(formats[i]),
-                                         COLUMN_TEXT, preview, -1);
-      g_free (preview);
-
-      if (has_active == FALSE
-          && !panel_str_is_empty (active_format)
-          && strcmp (active_format, formats[i]) == 0)
+      if (preview)
         {
-          gtk_combo_box_set_active_iter (combo, &iter);
-          gtk_widget_hide (GTK_WIDGET (entry));
-          has_active = TRUE;
+          gtk_list_store_insert_with_values (store, &iter, i,
+            COLUMN_FORMAT, _(formats[i]),
+            COLUMN_TEXT, preview, -1);
+
+          g_free (preview);
+
+          if (has_active == FALSE
+            && !panel_str_is_empty (active_format)
+            && strcmp (active_format, formats[i]) == 0)
+            {
+              gtk_combo_box_set_active_iter (combo, &iter);
+              gtk_widget_hide (GTK_WIDGET (entry));
+              has_active = TRUE;
+
+            }
         }
+      else
+        g_warning ("Getting a time preview failed for format specifier %s, so "
+                    "omitting it from the list of default formats.", formats[i]);
     }
 
   gtk_list_store_insert_with_values (store, NULL, i++,
@@ -823,6 +859,9 @@ clock_plugin_configure_plugin_chooser_fill (ClockPlugin *plugin,
     {
       gtk_combo_box_set_active_iter (combo, &iter);
       gtk_widget_show (GTK_WIDGET (entry));
+      clock_plugin_validate_format_specifier (entry,
+                                              gtk_entry_get_text (entry),
+                                              plugin);
     }
 
   g_signal_connect (G_OBJECT (combo), "changed",
@@ -1019,6 +1058,8 @@ clock_plugin_configure_plugin (XfcePanelPlugin *panel_plugin)
                                               tooltip_formats);
 
   object = gtk_builder_get_object (builder, "digital-format");
+  g_signal_connect (G_OBJECT (object), "changed",
+                    G_CALLBACK (clock_plugin_validate_entry_text), plugin);
   combo = gtk_builder_get_object (builder, "digital-chooser");
   clock_plugin_configure_plugin_chooser_fill (plugin,
                                               GTK_COMBO_BOX (combo),
